
#include <Wire.h>
#include <Encoder.h> // leftover from physical encoder code
#include <Arduino.h>
#include <IRremote.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define VOLCB_ADDR (0x38) // address of the volume control NXP
#define REMOTE_VOLUME_UP 0x13    // volume up IR remote command
#define REMOTE_VOLUME_DOWN 0x14  // volume up IR remote command

// display defined
#define SCREEN_WIDTH 128
#define SCREEN_HEIGHT 32
#define OLED_RESET -1
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);


const int IR_RECEIVE_PIN = 3;  // ir receive pin

byte currentAttenuation = 0x3F;  // current attenuation, initially max attenuation

void setAttenuation(byte attenuation) {
  Wire.beginTransmission(VOLCB_ADDR);  // transmit to U1
  Wire.write(attenuation);             // send the attenuation value to U1

  byte transmissionResult = Wire.endTransmission();  // end transmission and check for success
  Serial.print("Transmitting data to PCF8574A: ");
  Serial.print(attenuation, HEX);  // Print the data in hexadecimal format
  Serial.print(" - Transmission result: ");
  Serial.println(transmissionResult == 0 ? "Success" : "Failed");  // Print transmission result

  Serial.print(F("setAttenuation function sent value: "));
  Serial.println(attenuation);

  Wire.endTransmission();
}




void setup() {
  Serial.begin(115200);

  IrReceiver.begin(IR_RECEIVE_PIN, ENABLE_LED_FEEDBACK);

  Serial.print(F("Ready to receive IR signals at pin "));
  Serial.println(IR_RECEIVE_PIN);

  Wire.begin();                        // join I2C bus
  setAttenuation(currentAttenuation);  // set the initial values
  Serial.print(F("setup initial attenuation "));
  Serial.println(currentAttenuation);


  if (!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) { //  initialize and test display
    Serial.println(F("SSD1306 allocation failed"));
    for (;;)
      ;
  }

  display.display();  // Clear the buffer
  display.setTextColor(SSD1306_WHITE);

  displayCurrentAttenuation();
}

void displayCurrentAttenuation() {
  display.clearDisplay();
  display.setTextSize(3);
  display.setCursor(0, 8);
  if (currentAttenuation == 0) {
  } else {
    display.print("-");
  }

  display.setCursor(20, 5);
  display.setTextSize(6, 4);
  display.print(currentAttenuation);
  display.setTextSize(2, 4);
  display.print(" dB");
  display.display();
  delay(100);  // Adjust delay as needed
}

void handleRemoteCommands() {
  if (IrReceiver.decode()) {
    Serial.println("IR command received");
    unsigned long value = IrReceiver.decodedIRData.command;  // Get the received value
    Serial.print("Received command: ");
    Serial.println(value);
    if (value == REMOTE_VOLUME_UP && currentAttenuation > 0) {
      Serial.println("Volume up command received");
      currentAttenuation -= 1;  // Increase volume
      setAttenuation(currentAttenuation);
      displayCurrentAttenuation();
    } else if (value == REMOTE_VOLUME_DOWN && currentAttenuation < 63) {
      Serial.println("Volume down command received");
      currentAttenuation += 1;  // Decrease volume
      setAttenuation(currentAttenuation);
      displayCurrentAttenuation();
    }
    Serial.print(F("currentAttenuation set by handleRemoteCommands: "));
    Serial.println(currentAttenuation);
    IrReceiver.resume();  // Receive the next value
  }
}


void loop() {
  handleRemoteCommands();  // Check for remote commands
}